# $Id: /local/CPAN/Handel-Storage-RDBO/t/lib/Handel/Checkout/Plugin/NotISAPlugin.pm 1243 2008-01-20T04:05:18.816539Z claco  $
package Handel::Checkout::Plugin::NotISAPlugin;
use strict;
use warnings;

sub new {
    return bless {}, shift;
};

1;
