# $Id: /local/CPAN/Handel-Storage-RDBO/t/lib/Handel/Checkout/TestMessage.pm 1243 2008-01-20T04:05:18.816539Z claco  $
package Handel::Checkout::TestMessage;
use strict;
use warnings;
use base 'Handel::Checkout::Message';

1;